FieldInfo class

Form alanı bilgilerini tutan sınıf

Constructors

FieldInfo({required FieldType type, required String name, required String label, bool isRequired = false, String? hintText, List<String>? options, InputDecoration? decoration, TextStyle? textStyle})
FieldInfo.parse(String definition)
Alan tanımını ayrıştıran metot
factory

Properties

decoration InputDecoration?
final
hashCode int
The hash code for this object.
no setterinherited
hintText String?
final
isRequired bool
final
label String
final
name String
final
options List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textStyle TextStyle?
final
type FieldType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited